@@ -1,3 +1,7 @@
+import gmsh
+
+__gmsh_version__ = gmsh.__version__
+
 try:
     # Python 3.8
     from importlib import metadata
@@ -5,6 +9,6 @@ except ImportError:
     import importlib_metadata as metadata
 
 try:
-    __version__ = metadata.version("optimesh")
+    __version__ = metadata.version("pygmsh")
 except Exception:
     __version__ = "unknown"
