@@ -1,13 +1,14 @@
 from . import geo, occ
 from .__about__ import __gmsh_version__, __version__
 from ._optimize import optimize
-from .helpers import orient_lines, rotation_matrix
+from .helpers import orient_lines, rotation_matrix, write
 
 __all__ = [
     "geo",
     "occ",
     "rotation_matrix",
     "orient_lines",
+    "write",
     "optimize",
     "__version__",
     "__gmsh_version__",
