@@ -24,11 +24,11 @@ class Line(LineBase):
     def __init__(self, env, p0, p1):
         assert isinstance(p0, Point)
         assert isinstance(p1, Point)
-        id0 = env.addLine(p0._ID, p1._ID)
+        id0 = env.addLine(p0._id, p1._id)
         self.dim_tag = (1, id0)
         self.dim_tags = [self.dim_tag]
         super().__init__(id0, [p0, p1])
 
     def __repr__(self):
-        pts = ", ".join(str(p._ID) for p in self.points)
-        return f"<pygmsh Line object, ID {self._ID}, points ({pts})>"
+        pts = ", ".join(str(p._id) for p in self.points)
+        return f"<pygmsh Line object, ID {self._id}, points ({pts})>"
