@@ -15,8 +15,10 @@ class SurfaceLoop:
     reverse orientation).
     """
 
-    dimension = 2
+    dim = 2
 
     def __init__(self, env, surfaces):
         self.surfaces = surfaces
-        self._ID = env.addSurfaceLoop([s._ID for s in surfaces])
+        self._id = env.addSurfaceLoop([s._id for s in surfaces])
+        self.dim_tag = (2, self._id)
+        self.dim_tags = [self.dim_tag]
