@@ -24,7 +24,7 @@ class Volume:
     (in which case the two surface loops should be combined).
     """
 
-    dimension = 3
+    dim = 3
 
     def __init__(self, env, surface_loop, holes=None):
         if holes is None:
@@ -34,4 +34,6 @@ class Volume:
         self.holes = holes
 
         surface_loops = [surface_loop] + holes
-        self._ID = env.addVolume([s._ID for s in surface_loops])
+        self._id = env.addVolume([s._id for s in surface_loops])
+        self.dim_tag = (3, self._id)
+        self.dim_tags = [self.dim_tag]
