@@ -1,3 +1,5 @@
+from typing import Optional, Tuple, Union
+
 import gmsh
 
 
@@ -17,7 +19,12 @@ class Disk:
 
     dim = 2
 
-    def __init__(self, x0, radius0, radius1=None):
+    def __init__(
+        self,
+        x0: Union[Tuple[float, float], Tuple[float, float, float]],
+        radius0: float,
+        radius1: Optional[float] = None,
+    ):
         if len(x0) == 2:
             x0 = [x0[0], x0[1], 0.0]
         assert len(x0) == 3
